@@ -20,7 +20,7 @@ def main(config: dict):
 	not_used = ""
 	for texture in unused_textures:
 		path = f"{config['textures_folder']}/{texture}"
-		not_used += (f"\n'{path}.png' not found in the resource pack")
+		not_used += (f"\n'{path}.png' not used in the resource pack")
 	if not_used:
 		warning("Some textures are not used in the resource pack: " + not_used)
 
